@@ -20,9 +20,11 @@
 # If not, see <https://www.gnu.org/licenses/>
 
 
-from .general import Time, Angle, sin, cos, tan, cotan
+from .general import Time, Angle, sin, cos, tan, cotan, refraction
 from .earth_motion import Earth
-from .sun_motion import Sun
+from .sun_motion import Sun, SunObservation
+from .tables import generate_table, sunset_table, extend_table
+from .locations import Location
 
 # from importlib.metadata import version (only for python 3.8+)
 from importlib_metadata import version
